Welcome to our World! Where we serve you cookies to ensure you get the best viewing experience on our site.

Did you know that you can remove censorship board-wide, use our advanced search functions, be notified when new content is posted, join our memberships, set episodes to show in any order you want & more if you are logged into your account?

Register or sign in here: ucp.php?mode=register

Resynator (2024)

Curious minds want to know... Documentary Movie collection.
Watch Docus Amazon   Docus Merchandise

Documentary movie collection.

Resynator (2024)

Post by bunniefuu »

YOUNG ALISON (voice-over):

Hi, my name is Ali Tavel,

and I'm the one

who's gonna record this.

-TAMMY: Well, hi, Ali.

-Hi.

How are you doing?

(laughter)

ALISON (voice-over):

Dear Don, this is me.

-Hi.

-TAMMY: Hi.

ALISON (voice-over): You've

missed a lot over the years.

TAMMY:

There she is.

She's a-dancing on that table.

ALISON (voice-over): I was

always such a curious kid.

I'm Ali Tavel, reporting.

(voice-over): Mom built this

magical world for Lexi and I

to be loud and weird

and messy and creative.

-TAMMY: Ah! There they are.

-(laughter)

ALISON (voice-over):

She encouraged me to be me.

-TAMMY: Know what that is?

-ALEXI: Oh, my God!

Your own recording studio.

-Oh, my God.

-Ali, you can sing along

and record your songs.

-You can play back your voice.

-Oh, my God.

ALISON (voice-over):

I've always loved music.

Everything about it.

And everyone told me

I got that from you.



When I was in the fourth grade,

I decided to do a report

about the synthesizer,

because our family told me

you were this genius musician

who played with Stevie Wonder

and B. B. King

and was friends

with Steve Wozniak

-and invented the synthesizer.

-(camera clicks)

So I went to the library

at my school

and checked out

the "S" encyclopedia,

expecting to see, "Synthesizer:

invented by Don Tavel."

But your name wasn't in it.

It made me question

if any of the stories

about you were true.

And these stories were

all I had to connect to you,

because you died in a car crash

when I was ten weeks old.

So I never knew you.

I didn't end up doing my report

on the synthesizer,

and it would be years before

I ever thought about you again.

(indistinct chatter)

(indistinct voice over speaker)

Okay, real fast,

I'm gonna take your tambourine

-and your drink to stage...

-GRACE: Okay.

...and-and your, and your cape.

All right, let's go to stage.

(music playing in distance)

ALISON (voice-over): I'm 25 now

and I tour for a living.

I work for Grace Potter.

She's my boss,

but she's also my best friend.

I got to grab her.

-We got, we got minutes.

-Okay, I got to go get ready.

-All right, okay, here we go.

-Let's go this way.

I'm gonna put

my fringe vest on.

(speaking inaudibly)

ALISON (voice-over):

I'm not a musician,

but I'm surrounded by them

because of this job.

Hey, Jackson, you've got

five minutes to stage.

GRACE:

Jackson, thank you so much.

MAN:

Have a great set, Jackson.

(indistinct chatter)

Everybody's got ears

and packs, right?

-MAN: Yes.

-Okay.

(audience cheering)

GRACE:

All right, guys.

ALL:

One, two, three! (shouting)

ALISON (voice-over):

And being on the road,

around all of

these creative people,

with their gear

and instruments,

it made me curious again,

after all these years...

...about the synthesizer

you invented.

I'd known my whole life

that it was stashed away

in a box

somewhere in the attic.

An abandoned mystery

for 25 years.

But maybe it was finally time

for me to go find it.

(footsteps approaching)

Hmm.

Oh, no way.

B. B. King guitar pick.

My family always said

that my dad had,

uh, played with him

before, so...

Let's see what we got here.

That's cool.

Okay.

So this is...

No.



I bet this is it.

This is it.

The Resynator.

DON (voice-over):

The synthesizer takes advantage

of computer technology.

Simply by playing a note

on my musical instrument--

in this case, the guitar--

and the computer will then

set the FX oscillator up

to that interval.

The oscillators

will be responding

to my guitar input

via a Digital

Frequency Analyzer.

The final computer aspect

is the Timbral Image Modulator,

and I'll be using

a variety of shapes.



(birds chirping)

-(knocking on door)

-ALISON: Knock, knock.

-BRIAN: Hey. How are you?

-Hi.

-Alison.

-Good to meet you.

Nice to meet you.

So, everyone says

you're the person to talk to

about synths, so, I, uh,

I have a rare one,

and when I got it

out of my grandma's attic,

I was looking for a keyboard.

-Mm. -'Cause I thought that

that's what a synthesizer was.

And then I pulled out this,

like, black rectangular box

with a bunch of knobs on it.

From what I can remember,

it's a "rack-mount,

"monophonic,

instrument-controlled,

s-- p-pitch-tracking

synthesizer."

(both laugh)

But I don't know

what any of that stuff means.

Basically,

a pure synthesizer,

in theory, can do any sound,

any direction of sound,

any kind of combinations.

But that's

a pure theoretical concept.



(voice-over):

When synthesizers came out,

this was a whole vista

of new sounds

that we haven't heard before.

(beeping, buzzing)

The most commercial

and usable system

was Bob Moog's system.

(synthesizer music playing)

This became a clich that

people consider a synthesizer

as something

with a keyboard attached.

The Resynator is a mystery

because it's a black box

which is full of potential.

Your synthesizer is in there

ready to make notes and sounds,

but is controlled by

an instrument or a voice.

(Resynated music playing)

Don was in the first wave

of people

using computers

to try to track pitch.

But the heart of it

is an analog synthesizer,

and that's the key part of it

because a lot of instruments

are one or the other--

but not both.

No one ever made

a successful instrument

that was controlled

by outside sounds,

but it seems your dad

had figured out a way

to make it work.

ALISON (voice-over): If you

really had invented something

so revolutionary, then why

did I have the only one?

Not knowing anything

about the synth,

or your plans for it,

made me realize that I also

didn't know anything about you.

REPORTER:

On "Indy Alive,"

we promise you

all types of things.

Now, you may be thinking

that's an organ,

but that's really a guitar,

and you're listening

to the music of Don Tavel.

How'd you get interested

in this kind of music?

Well, I got into electronic

music when it started, uh,

pretty much in the '60s,

and, um,

I followed that involvement

through into the '70s,

and we got into using

computers, uh, early on in,

uh, in the early '70s,

through the mid-'70s,

and then I ended up inventing

and, uh, holding seven patents

on the precursor to MIDI.

You have seven patents?

-Yes.

-That you've created yourself?

Yes, on a Musical Instrument

Digital Interface

similar to MIDI,

and I was a member

of the first conference

on MIDI, uh,

to try and develop a standard.

ALISON (voice-over): The reason

why I wanted to come here

is because

the Resynator project

has led me to being open

to finally,

finally wanting to know

who Don was as a human.

When Don was graduating

from the School of Music,

he had to give a performance.

-DON: Maestro.

-(synth music plays)

LARRY (voice-over):

He had taken guitar pickups,

-and he put them on a strap

to his head... -ALISON: Uh-huh.

LARRY:

...and with his thoughts,

he controlled the music

and the lights.

The Resynator, though, right?

It was that?

It was an early version

of the Resynator.

KITTY (voice-over):

I couldn't believe

what we were watching.

I mean, it was just wild.

The dean

and the faculty members

all crowded around us,

remember?

And they said,

"Congratulations.

You have a genius for a son."

(chuckles):

Remember?

And I looked at his father,

I said,

(laughs):

"Who wants a genius for a son?"

(laughter)

Did he ever voice

a goal for you guys?

Like, did...

I mean, the Resynator,

he had plans to produce it...

-Oh, absolutely.

-...but then he didn't.

So, I just wonder what, um,

his reasoning

for not moving forward

with the-the production

anymore.

Um, I can't

really address it...

-Yeah. -...other than to say

that I think that,

uh, it was just

an economic decision

to move on to the,

to the next thing.

But absolutely,

his plan was to be

in the music industry,

in the electronics industry,

and pushing the envelope.

ALISON (voice-over):

I once again found myself

hearing stories about you,

but not being able

to relate to any of them.

You have to know-- I know why

they love music and art:

because I did it to them.

(voice-over):

I made it a rule.

One year of piano was a must.

You had to have

an introduction to music,

and you couldn't escape it.

LARRY (voice-over):

The Beatles were coming up,

and he picked up a guitar,

and the guitar became,

like, his third arm.

Donnie played

as many as 17 instruments.

He worked with Stevie Wonder.

He had the opportunity

to play with B. B. King.

One of the members

of the Average White Band

flew out to Indiana

to spend some time with him.

DEBORAH (voice-over):

His vision was

putting the music

and the technology together

way before anyone else

even thought of it.

He founded the Department of

Computer and Electronic Music,

and donated all kinds of

computer equipment

to get the thing started.

DOUG (voice-over):

I met Don, I think, in 1971.

And I remember him

coming up with the idea

of doing silk screens

of waveforms.

That's my memory of how he

connected the music department

to the art department.

Don being here was

the seminal moment

for the implementation

and beginning of

music technology here.

He lived up to,

what I think, genius.

I want to hear the normal--

even if they're not interesting

to you,

they're interesting to me--

the-the normal stories,

the-the everyday stories.

To-to try to get a better idea

of who Don was as a...

as a person, not as a genius.

There's a lot of stories,

many that

probably can't be told here.

(laughs)

See, that's what

I'm looking for.

(both laughing)

I'm looking for those stories.

LARRY (voice-over): He could

do just about anything.

He could carve wood.

ROGER (voice-over): He used

his VCR as his hard drive.

LARRY (voice-over):

He was a phenomenal athlete.

KITTY (voice-over):

He was kaleidoscopic.

LARRY (voice-over):

Everybody knew-knew Donnie,

and everybody in the country

knew about what he was doing.

Did he ever do anything crazy

in high school that...

-Did he ever do anything wrong?

-And I won't tell you. (laughs)

-You should tell us, though.

-Another time.

I can't handle a lot of this.

ALISON:

Aw.

-Hi.

-TAMMY: Baby!

-ALISON: Hi, mama.

-Mwah!

Oh, my gosh,

it's so good to see you.

-ALAN: Hi, sweetie. Hi.

-ALISON: Hi. -(kisses)

Hold on,

let me get out of the car.

Mmm. Mm-mm!

(chuckles)

-Hi.

-Hi, babe. Mm.

TAMMY (voice-over):

So where have you been?

I can hardly keep track.

Someplace new every night.

We were in New York yesterday

at that ESPN event.

Yeah.

ALISON:

And, um, we-we were in Houston,

'cause we went to

the NASA Johnson Space Center.

TAMMY:

Oh, right, right, right.

So Alan prints this out.

-ALAN: Yeah, this is where...

-TAMMY: And we know exactly

where you are every day.

Almost.

We have to call you and

tell you what city you're in.

ALISON: What website is this,

ConcertBoom?

Oh, I don't know.

It's-- it was a Grace Potter...

Well, also our first show

was in, um, Chattanooga.

TAMMY: Well, that's probably

on the other sheets

-I have over there.

-Oh.

-(Tammy laughs)

-ALAN: Hey, look.

How should we know

where you are

when you don't even know

where you are?

(chatter fades)

ALISON (voice-over):

Mom met Alan in 1997.

Before that,

it was just me, Mom and Lexi.

Here's the garden.

Such a nice

and beautiful thing.

ALISON (voice-over):

And I couldn't have imagined it

any other way.

But eventually,

Alan became part of our family,

and he was the one

who drove me to school,

put up with my tantrums

and answered my questions.

He was my dad,

and he loved my mom.

ALAN (voice-over): In all

the years we've lived together,

I've never seen one day that

she hasn't come down the steps

without a smile on her face.

-Oh, and you, too, baby.

-(laughs)

There's something wrong.

-We come down and we smile at

each other. -It's like, "Oh..."

-Hey, what the hell's going on?

-(laughing)

(laughter)

ALISON: Okay, Mom,

let's watch this wedding video.

-TAMMY: Oh, my goodness.

-Oh, there's me.

I have-- I love this,

like, three-foot

-tulle ribbon in my hair.

-Yeah.

Bow.

ALISON:

What'd you do with the ring?

TAMMY:

It's right over there.

-You still have it?

-I...

I still wear it sometimes

on my little finger.

Oh, is it the one...?

It's got rows

of little teensy diamonds

-and...

-ALISON: Oh.

-TAMMY: God, I was so skinny.

-I know.

(laughter)

TAMMY: I told him it was

the best day of my life,

except for having Alexi.

It was the happiest day

of my life.

(laughs)

(voice-over): I'd already

divorced my first husband

and had Alexi when I met Don.

It was a blind date.

And we went out.

He drove to my art gallery

on a Friday night

from Indianapolis.

Had a really nice evening.

And I thought, "Wow, this is--

he's really cool."

And he's a musician.

I go,

"Ooh, that's really interesting

because I love music."

Started dating after that.

I would watch him in concert.

He'd, you know,

be doing his shows and just--

I was, like, in awe of him.

Just incredible.

He was very...

charming.

Very charming.

Um, very caring.

It was about a year later,

we got married.

You know, we had the reception,

and we went on our honeymoon.

And then everything

started to change.

(Alison exhaling softly)

1970s.

Hey, have you guys

heard of Mu-- Mu-Tron?

I'm going to meet

the founder tomorrow.

He-he engineered

the Resynator for my dad.

-MAN: No way.

-Yeah, Mike Beigel.

Yeah, that's-- I see that here.

S-Stevie Wonder?

ALISON:

Yeah, he's gonna help me

resurrect it, hopefully.

MAN:

So cool.

(doorbell rings)

(dog barking)

-Hi. Are you Mike Beigel?

-Hello. Hello.

Oh. (laughs)

Okay, great. Thank--

Hi. Hey, buddy.

-Hi, I'm Mike.

-Hey.

-(laughs)

-Good to meet you.

Nice to meet you.

MIKE:

Come on in.

I am.

Well, just have a seat.

Thank you.

MIKE (voice-over):

So I was going through

the NAMM show,

which is a very big show

of musical products

and giving out

my new little business cards to

anyone I saw, and on, I think,

on the last day,

uh, this guy making

the music synthesizer

is coming after me

and wants to talk to me.

He says, um, he's Don Tavel.

And his product

is the Resynator.

And he decided that,

uh, I looked like the guy

he needed to help him

finish off a couple of details.

I have, I think,

what would be called,

like, the-the software

inside of it.

You have--? Good.

Um, it's wrapped in bubble wrap

in the back seat of the car.

The software is wrapped

in bubble wrap?

Well, the-the hardware

that goes inside.

Um...

The software...

-is...

-Like, the disc things.

-Ah.

-You know what I mean?

Okay, good. It might be

a little hard to figure out.

It's quite possible that

the little computers might've

lost their memory by this time.

-Right.

-Was there a manual?

Was there ever a manual?

I don't remember

if there was ever a manual.

Nothing that I came across.

There was only one person

who could really play it right.

Don?

Yeah.



ALISON: This... this looks

like a labyrinth to me.

-MIKE: Yeah, well.

-Like a foreign language.

MIKE:

So, take a look at that,

inside of the one known,

possibly working Resynator.

So, I'm gonna put

the oscilloscope on,

then I'm going to push on, on.

And we have...

ALISON:

Is that what we want?

MIKE:

That's what we want.

ALISON:

Well, that's a good sign.

MIKE:

Now let's find out

what the controls

on this thing are. (chuckles)

I forget.

"FXO..."

(electronic chord plays)

So this switch is working.

(electronic notes playing)

Now that's working.

(electronic buzzing)

I would say 60%, yes, works.

ALISON:

I mean, honestly, this is

more than I could have

hoped for at this point today.

-More than nothing, hey?

-So I'm excited about it.

Okay, but now we can see

if I can remember

a few things...



ALISON (voice-over):

Standing next to Mike Beigel,

I'm looking at the schematics.

And he's asking me to read off

some numbers from it,

like "R54" and "22K."

And I just imagined

that this was

the same situation

that you were in

when you were creating this

with Mike.

Up until this point,

you were just

a collection of stories.

This was the first time

I felt like you were a person

instead of an idea.



(voice-over, voicemail):

Hi, Mike. It's Ali.

Um, it was so nice

to meet you yesterday.

Thank you again for helping me

with this project.

I was thinking if we could

get it working in time

to bring it to the NAMM show,

like, 35 years or whatever,

after you and Don did it

to reintroduce it,

it would be so cool.

Um, I know I'm probably

getting ahead of myself.

I'm just kind of excited, so...

We'll talk more soon.

I'll be home from tour soon,

and we can figure out a time

for me to come back down

and see you.

I hope you're doing well.

I'll talk to you soon. Bye.

Look at all

your "Musician" magazines.

GORDON: Oh, yeah, it is

the, uh, Hall of Fame here.

Yes, exactly.

And I remember that one because

there's a Resynator ad in that.

Oh, in that issue, right.

(voice-over): Yeah, Don Tavel

and I were very simpatico.

We both were, uh, little guys

fighting in a big,

uh, big guy world.

We both believe we could, uh,

be the Man of La Mancha

and the impossible dream.



He was trying to invent

a product

that you could use

on every song.

And it would change.

It would be like a violin.

It would be like an oboe.

It would be like, you know,

crashing or cacophonic.

I think that he was looking for

big names to do it, obviously,

for marketing purposes.

In a way, people all say,

"Oh, boy, Paul McCartney's

using it. I use it."

That's where you, if you got

those superstars going at it,

then you'd have a sound

that was even sweeter.

This was where he, uh,

spent his last night,

-period.

-Yeah.

GORDON:

And-- 'cause the next day,

I remember him leaving.

Let's see.

Your dad died, I thought,

on November 28th, 1989.

-1988. The year I was born.

-'88, okay.

The year you were born.

And in '88, they had

just acquired this, um...

You were born in '88. Okay.

I was born September 14th.

This coming Sunday

is my birthday.

-Wow.

-So he died ten weeks later.

Wow.

And do you know much of

the history behind that?

-Behind my dad? Or...

-Yeah.

Well, I grew up

telling everybody

he invented the synthesizer.

(both laughing)

Have you spoken to

Emmett Chapman?

Um, I was supposed to

meet with him.

-I haven't met with him yet.

-Okay.

-I will this fall.

-He's a brilliant guy.

-He is like a Svengali.

-I can't wait.

He is like, absolutely, uh,

Gandalf in...

from "The Lord of the Rings."

-(laughs)

-He is incredible.

The reason I asked

if you'd talked to Emmett is,

he seems to have

similar memories as I do,

where I wondered

if you would start out

making this movie about Don

inventing the Resynator

and, like, some, uh,

action thriller

or "Adaptation."

You know that movie?

Where you'd end up--

the movie would really be about

what happened to your dad.

Because, uh, and I don't mean

to be negative,

but, uh, it was, uh,

my impression that, uh,

not to be too cold

and cruel about it,

but when he came,

his final week here,

which was a week

after you were born,

it was a tough week

because he basically said

the day you arrived, and

they were getting along fine,

you were delivered,

put in your mother's arms.

He came in and went,

"Ah, goo-goo,"

and she turned to him, said,

"And now I want a divorce.

I don't want to be

married anymore."

And that was it.

And then Don

absolutely freaked out

and was so crazy about you

and was so depressed

and, uh, was thinking

bad things about himself

and his continuation,

and came here,

and we spent the whole week

-just talking him down.

-Yeah.

And just, you know,

it seemed like,

um, those that knew him,

uh, have said, you know,

"Oh, I don't think

he ever would hurt himself."

And I wasn't so sure,

because he was so depressed.

All he kept saying is,

"I just don't know

how I'm going to go on."

So, I don't know.

You know, I-I had my doubts.

I think Emmett has his doubts.

-Mm-hmm.

-You know?

-I mean, if it was an accident?

-That sucks.

Maybe that's

a better thing, you know.

-And if it's not, that sucks.

-Yeah, yeah.

-Yeah.

-Anyway, but, uh...

ALISON (voice-over,

over phone): Hi, Mama.

TAMMY (voice-over, over phone):

Hi, honey. How are you?

ALISON: So, I just met

with Gordon Baird.

He actually said something

kind of off-putting.

He, uh...

he said he thought

Don k*lled himself.

I mean, do you think

Don k*lled himself?

TAMMY:

Well, you know, Ali,

I always had my suspicions.

Um, he wrote

a letter that I have.

ALISON:

Is it a suicide note?

TAMMY:

No. No, I wouldn't say that.

Um...

you know, it was more a note,

I think, just to get

these thoughts out of his mind.

I have it saved for you,

and whenever you want,

whenever you come home,

I have it for you, okay?

ALISON:

Okay.

TAMMY (voice-over):

It was really sad,

I mean, how I found out,

really, after I got married,

of who he was.

He would leave

nasty little notes around.

I was, like, a-- maybe

a month away from having Ali.

I mean, I was very pregnant,

and he got angry at something

and pushed me

clear across the kitchen,

and I ran right into the stove.

Um, another time,

where he got so angry at me

as I was walking down

to the lower level,

and he grabbed me, like,

around the neck.

It-it-it frightened me,

literally frightened me.

After Alison was born, um,

I mean, he's so incredibly

wonderful in the hospital,

and we bring her home,

and I thought,

"Oh, this is great.

Everything's gonna be

wonderful."

And then, all of a sudden,

he started just being

so upset with everything.

He just did not seem happy.

And you would think

that this was going to be

the happiest time of his life.

He threatened to throw me out.

I went to my sister's house.

I contacted attorneys.

I said,

"Something's got to happen

"because I'm not getting thrown

out of here.

I just had a-a baby."

So they got

a restraining order,

and I'm sure

that he was, like, in shock,

but you don't threaten someone

and not expect some reaction.

(sighs)

I never, ever wanted her

to think badly of him.

So, even growing--

even when she was little,

"Okay, these are

your dad's guitars.

He was amazing," this and that.

There's no reason...

I had no idea

what his problem was,

what was in his head.

I just knew he was generous,

he was loving, he was...

this amazing genius,

and that's all she needed.

She didn't need to know...

She wasn't...

part of that, really, you know?

She was three months old

when he had this accident,

so why think badly of him?

(quiet rummaging)

Huh.

-ALISON: Hey.

-EMMETT: Oh, hello.

-Alison. -It's so nice

to finally meet you, Emmett.

Oh, thank you. Same to you.

I've been wanting to do this

for a long time.

Me, too.

Yeah, that's good.

Here's a photo,

the only photo I could find,

-and I did search.

-Oh, my gosh, I haven't seen...

EMMETT: I searched till 3:00

in the morning last night.

I wanted to give it to you.

ALISON:

Oh, thank you.

When I met with Gordon,

he was very--

um, he just had

some very shocking ideas of

the last couple of days

of Don's life,

because he tells me

that he thinks that

-Don k*lled himself...

-Mm-hmm.

...because he was

really dark and depressed.

And then he mentioned you

and said that...

He said he had his doubts,

and he thought

you had your doubts,

and that kind of

opened up my whole...

um, that changed

my perspective of Don.

That was really

the first thing I'd heard

that was not this bright,

beautiful, positive thing,

and it made me

ask a bunch of questions.

What he said was

right to the point.

I had to agree,

but I can't know for sure.

-Yeah.

-And if-if Don had

this dark side,

it might have been caused

by their relationship.

I think he repressed

his emotions when he was a kid,

and he had this intellect

to be able to do that.

You know, sometime I think

maybe he paid the penalty

for emotional repression.

Would be like stopping

his emotions from growing

during a teenage period,

where he accentuates

his intellect instead.

And then you pay the price.

And it could have been paid

with his marriage.

I had never heard of

any of that before.

Like, nobody has ever

told me those--

that side of Don before.

When I started

breaking him down

and learning about, like,

through Mike Beigel

and Gordon Baird,

and why I've been

so excited to meet you,

is just 'cause

you guys knew him

away from all of that.

His brother,

whose name rhymed with his...

-RJ, his twin.

-Was it Ron?

-Ron.

-Ron and Don.

Was amazing to see

two guys that look alike

and were totally different.

Don told me,

in a moment of confession,

that he kind of

felt humiliated about it,

but when he was in high school,

they called him "Robot."

-They called Don "Robot"?

-Yeah.

He hated that name.

-Really?

-Yeah.

But then, in-- uh, later on,

he was totally different.

He was like his brother.

He-he was dapper

and, uh, and witty

and, uh, very sociable.

He changed from, like,

from one year to the next.



ALISON (voice-over):

I could never be myself

around Grandma Kitty.

And there were so many things

I was never allowed

to talk about with her.

Like the fact that you had

an identical twin brother: RJ.

I technically met him once

when I was a baby,

but I've had no idea

where he's been since

because he and the family

haven't really spoken

since you died.

DEBORAH (voice-over):

Our parents were,

they were the country club

kind of people.

They painted pictures of

what they wanted

their children to be,

and, you know,

they had

very high expectations.

It was

a very domineering, uh, world

that we were living in,

and he was part of that.

Don told me that he had

an ulcer at the age of nine.

I could not believe it.

(laughs): I didn't know

that children got ulcers.

But I think

he was just such a...

a nervous wreck at that age,

trying to please his parents.

ROGER:

Don, in a way, was shy.

Having conversations

with people

that he didn't know

was not easy for him,

so he hid behind his guitar.

RAY RICE: This fellow's

name is Don Tavel.

He's president of Musico,

which is a company

which makes Resynators.

We're not gonna talk

about that tonight,

but we should tell you

that a Resynator,

simply stated, is a device

that synthesizes the sound

of musical instruments

and does it far cheaper

than other equipment

produced in recent years.

(voice-over):

This is a graphics board,

not something really new,

but it can now be applied

to home computers.

DON (voice-over):

You can do commercial work,

doing people's logos,

uh, with computer graphics.

You can do cartooning as well,

such as Superman flying.

You can do, uh,

fine art, uh, portrait work.

RAY (voice-over):

Albert Einstein.

Have to have some skill

though, I mean,

to be able to do that at home.

DON: Yeah, computers

won't replace talent.

(Don and Ray laugh)

GRACE (recorded): Hey,

this is Grace. Leave a message.

(answering machine beeps)

ALISON (voicemail):

Hey, Grace.

Um, I just texted you a photo

of this letter that I found.

It's a company called

Syco Systems.

That I guess it was a company

Peter Gabriel

owned in the '80s.

And it looks like they bought

three Resynators.

And Peter had

personally requested one.

(laughs) Uh, so that's amazing.

And I found

all kinds of cool things.

So, it's all good stuff,

but there's some other

not-so-fun things

that I found out,

um, that I need

to tell you about, too.

So, just call me when you can.

(voice-over): There's this

whole different side of you

that I'm learning about.

I always felt like there was

more to the story with you.

But I never

would've imagined this.

And I don't know

how I feel about any of it.

I can't understand what you

might've been struggling with.

Because you just seemed to have

everything going for you.

MIKE: Don Tavel is going

to demonstrate a device.

This is actually an instrument-

controlled synthesizer.

Go ahead, Don.

DON:

Okay. So, what I'm gonna do

is go through several

acoustical instrument sounds.

(trumpet-like notes playing)

Well, if I drop the sound

an octave...

...and increase the breathiness

a little,

we come up with a tuba.

(tuba-like notes playing)

And change the Timbral Image

Modulator waveshape

to a fluttering pattern...

(flute-like notes playing)

ELECTRONIC VOICE:

The Resynator.

MIKE:

(chuckles) Got that in.

Thank you, Don.

(applause)

I remember one thing

that Don used to tell people

when he was demonstrating,

if you got it rigged up

to sound like a trumpet,

you have to think

you're playing a trumpet.

When a person absorbs

that idea,

uh, it completely

transforms the way,

uh, a person plays into it.

There was one time

we brought this thing

-over to Stevie Wonder's place.

-BRIAN: Ah.

Don wanted to sell this.

Well, Stevie Wonder wasn't

buying anything. (chuckles)

-Mm.

-It was so stupid.

We should give it to him.

We never actually, um,

tried out that many things.

-(Alison laughs)

-Yeah.

Wh-When we finally got

these things together,

um, we didn't do much

after that.

Well, that's what I'm still

trying to figure out

is what happened after the...

after the marketing

in "Musician" magazine

and "Sound Design" magazine

and the speaking, um,

conference at MAC '81, like...

MIKE: Yeah, there was a lot of

advance publicity on the thing.

BRIAN:

Mm.

From what I'm told, I think

six prototypes were made.

200 units were ordered

and not produced.

ALISON:

But never produced. Okay.

It's a lot of family dynamics

that went into

a lot of parts of Don's life.



BRIAN (voice-over):

People like the sound

of analog synthesizers.

They've gone back to them.

The same way guitar players

use old guitar amps,

the same way singers

like old microphones.

The Resynator is kind of

a lost Indiana Jones item.

This is a photo of

the rack-mount Resynator

that I have.

And there's a knob

on the left-hand side

that I-I can't read

what it says,

but that knob isn't

on the unit that I have.

So that means that

there's a Resynator out there

that hasn't been found yet.

BRIAN (voice-over):

Don invented his own terms.

He's not just copying

what other synths were doing.

He's trying to create

a kind of new playing field.

I feel like he wanted you

to use it in a different way.

Or to think of it differently.

I get a sense that he was

full of promise for it,

and I don't know

if it was crushing

that it didn't go forward.



(paper rustling)

Honestly, it's been a while

since I've even looked at this.

This is, this is it. This is

the only piece of writing

-that I have of Don's, so...

-Right, right, exactly.

Um...

The letter he wrote

and handed to me,

because we were going

to a marriage counselor,

and she said, "You need

to write your feelings down

and get them down on paper."

When I filed for divorce,

they automatically said

you need a restraining order.

Why?

Because of the abuse

and the little messages

that he'd left for me.

-Mm-hmm.

-And...

They thought that there was

some problems there.

-You ready?

-I'm-- Yeah.

Okay.

This was the original.

And his father goes, "Oh,

this... this is not right."

-Oh, my God.

-And he ripped it up,

and I glued it all

back together.

-Oh, my God.

-Yeah.

(sighs)

-Can I read it out loud?

-Sure.

"Dear Mom and Dad,

"I'm writing this letter

at age 35

"to tell you how unloved I felt

for my entire life.

"Mom, you had no idea

until they opened you up

that there were

two babies in you."

Is that true?

I cannot imagine.

I mean, is this in his mind?

I don't know.

ALISON:

"I was the unexpected baby.

"I grew up wanting the love

of both my parents,

"but I had to compete

with my three other brothers

"for any love at all.

"Without that love,

I sought recognition

"as my means for attaining

a measure of satisfaction.

"But the victories were hollow.

Instead of love, I got awards."

(chuckles softly)

"I didn't want awards.

I wanted your love.

"You were proud of me,

but you couldn't love me.

"If you were just like

everyone else,

"I could develop appropriate

dialogues and responses

"that would allow us

to function without mishap

"when we were together.

"I've done many things

to make you proud of me,

"and I know you're proud of me,

but I have never been able

"to find the way

to make you love me,

"and I hurt so deeply

because of this.

"Your life is ending,

but mine is still young.

"Now I'm married,

and I want to be loved.

"My wife is the only person I'm

allowing into my inner circle.

"But I am hounded by my anger

for a lifetime without love.

"I have nowhere to turn.

"I can't escape to calm down.

"So whenever I feel

I'm being unloved,

"I lash out in my desperation.

"I'm backed into

a corner emotionally,

"and I feel I must strike out.

"I can't do anything now about

the first half of my life,

"but I must not allow myself to

ruin the second half of my life

"misdirecting my anger

for you at my wife.

"She doesn't deserve that.

"She is powerless

to understand it.

"But the thought of being

married and unloved

"for the rest of my life

is so horrifying to me

"that I can go crazy

if I don't do something.

"I wouldn't be writing

this letter

if I wasn't

absolutely desperate."

-(sobbing softly)

-And then he says,

"Tammy, if after reading this,

"you want to talk to me,

I'd love to hear from you.

"If not, I'll understand.

"I'm sorry if I hurt you.

I love you. Don."

(sobbing)

Oh, my God, Mom.

Jesus Christ.



ALISON (voice-over): The person

who wrote that letter,

that's who I want to know.

It was hard to hear,

but you were honest,

you were raw, you were real.

I somehow had

never even considered

trying to find your twin

until now.

But I'm ready to meet him.

And when I finally

got in touch with him,

he said he'd like

to meet me, too.

You're looking at your dad

at 64 years of age.

Because when...

you say identical twins,

twins are identical

down to their cuticle.

So these are

your dad's hands, basically.

This is identical.

-The voice is close.

-Yeah.

Uh...

I would have to say, uh...

it probably was also close

because we both smoked

cigarettes for far too long.

-Yeah.

-So, the raspiness.

I didn't know he smoked.

-Oh, really?

-Mm-mm.

Yeah, well. (chuckles)

I knew Don smoked pot,

but I didn't know

he smoked cigarettes.

-He did it all.

-(both laugh)

I was just interested to think

how-how you think

you and Don were similar

growing up

and how you thought

you were different.

How close were you guys

growing up? That kind of stuff.

I think, I think all...

children growing up

chafe at close quarters.

And we were always

shoved together.

Uh, my favorite picture,

which it's a, uh...

a little Kodak Instamatic,

and it's...

me with my arm

thrown around your dad.

And I just got

this big smile on my face

because I couldn't think

of a better place to be

than next to my twin brother.

I want to show you this box...

-Yeah.

-...of heirloom pictures.

Tour T-shirts.

ALISON: Oh, my gosh,

old-school Grateful Dead.

Oh, yeah.

This one.

I want you to have this.

(voice-over): I really

don't know what to say.

When Don died, my mom wrote me

out of her life.

It was as if I died

in the car accident with him.

So, we haven't spoken.

And, uh, it was not

a good time.

It was basically

how the ball started rolling

so that I ended up here in...

(chuckles) Dillinger Country.

I don't think anyone

wants my theories

on why that collision happened.

I... almost was

generous enough to suggest

that it was an accident.

I don't believe it was.

He was my brother.

He just was.

And then he wasn't.

TAMMY (voice-over):

It was November the 28th, 1988,

and I got call

that he had been

in a horrible accident.

And that...

possibly he was not

gonna come out of this.

I think I was packing

to go to Florida.

And, uh,

I received a phone call.

I had to go to the hospital.

ROGER (voice-over): And so,

I started calling around

to friends and asking,

"What do you know?"

(voice-over):

He had been drinking.

I think the autopsy showed

that he had Valium

or something in his,

in his blood as well.

And he was driving too fast

around the curve

and lost control

and-and went off the,

uh, went off the road.

TAMMY (voice-over):

And so, in the hospital,

they did a CAT scan,

and there was

no brain activity.

(voice-over):

So then they wanted me to say,

"Okay, pull the plugs,"

but I said no. I--

That was up to his parents.

It was not up to me.

I don't want to relive

all this stuff, do I?

MICHAEL: We're getting--

going to the grave,

which I think is over here.

Do you know?

-ALISON: I-I don't actually.

-I... Should we pop out?

MICHAEL:

I've never been back.

-ALISON: Since...?

-MICHAEL: Since his funeral.

ALISON: So, he technically died

on the 3rd.

The crash was on the 28th.

It's two days before

my sister's fifth birthday.

Is that right? Mm.

Almost 28 years ago. Wow.

We always talked about

all the things we were gonna do

when we got older and retired

and all the fun

we were gonna have,

and that all got stolen away.

And 36 is so young.

You have your dad's smile

and his eyes.

Your resemblance is so strong.

It's, uh, it's nice,

but it's-it's-it's

tough, too, you know?

ALISON: I think I could

fool people if I

-put a mustache on my face.

-(both laughing)

-Not a good mustache either.

-No?

It was never a good mustache.

Yeah, your dad should not

have had facial hair, but...

I don't think

this is where your dad is.

This isn't-- to me, that's--

this is a...

this is a marker, that's all,

and just something for

other people to be able to...

-Pay their respects?

-...to visit him in a way,

but that's not, you know.



MICHAEL:

You okay?

ALISON:

Yeah.

MICHAEL:

I drive around this turn,

I think about your dad.

Not a single...

27 years' time, I've never,

never been able to, uh,

drive around it

and not think about it.

(turn signal clicking)

And I don't know exactly...

...but we're...

we're there.

It was a horrible week.

I mean...

Because it...

it never got any better,

and there was never

a moment of hope,

you know, from the very start

until the very end.

It never-- He never

had a moment of, you know,

anything like he was gonna--

They were gonna be able

to do anything, and...

ALISON:

I think, sometimes, my mom is

too nice to say anything bad

about anyone,

but at the funeral,

like, nobody would talk to her

except for you.

I wouldn't say nobody,

but the...

I-I think that your mom

was blamed

for his state of mind.

Uh, if he hadn't been

in that state of mind,

he wouldn't have been

driving too fast,

wouldn't have, you know,

been drinking

and-and doing Valium.

Um, I think

your mom was blamed,

and therefore,

she was, you know...

It-it w... it was their son

that was being buried.

It wasn't Tammy's husband.

-ALISON: Yeah.

-So...

Yeah, I think your mom

was-was shunned.

ALISON: It still doesn't

seem real... to me.

I mean, I'm sure

it's real to you guys

because you lived

through it, but...

...it's weird being...

This is where

he essentially died,

and that's where

he's essentially buried, and...

Sometimes he feels like my dad,

and sometimes it-it doesn't.

Like, right now, it doesn't

feel like my dad did this.

-MICHAEL: Mm-hmm.

-ALISON: And I don't know

-what that means.

-Mm-hmm.

I mean, now that

I've been here and done this

and did the, did the trek,

I'm glad that I did it

because I've always...

I haven't always wanted to, but

since I started this, and...

that this has been on my list

of things to do, you know,

because I should

do these things.

And they-they are helpful

in some way, but...

...the...

I don't know. I feel like...

...talking with you

and with Mike Beigel

and working on the Resynator

and stuff

is the closest I've ever gotten

to feeling like he was around.

But I'm glad that I did it.

I'm happy to, happy

to have been here with you.

-Thank you.

-Sure.

Any way of reconnecting

with him's good.



ALISON:

So, I am on my way

to Grace and Eric's house.

I just picked up the Resynator

from Mike Beigel.

He said it's calibrated,

and it's-it's ready to go.

He... he did everything

that he could,

but in order to really tell

if it's working properly,

you-you have to play it.

GRACE (voice-over):

You made it.

-Hey.

-ALISON: Mm.

Oh, my God, okay,

so here it is.

-Is Eric in the studio already?

-GRACE: Yeah, he's here.

ALISON:

Is he all ready for this?

GRACE:

I... He better be.

Okay.

Ooh.

-It's a big black box. (laughs)

-Come on.

(electronic tuning)

And this one, that one's...

-Whoa!

-That one's tuned.

-Okay. Now we got the tuning.

-(laughing)

There we go.

(electronic notes playing)

Yeah. It's a cool sounding

synth, you know?

Yeah. I love this.

It tracks really well.

So, I don't really understand

what this...

what-what, like, where's the...

-Like, what do you...

-What is this thing? -(laughs)

ERIC:

Where's the synthesizer part?

-What is this device?

-ERIC: Yeah.

Well, that's the question,

isn't it?

What-what is this thing?

Yeah, it-it's like

a cool blend between a synth,

which is, you know,

by definition,

a-a synthetically

derived sound,

but it's being triggered

by an organic instrument.

And so, it's like this

really interesting combination.

I think you should get as many

people to play with this thing

as possible and just see,

uh, what comes of it.

Take it elsewhere,

show people,

see what it sparks.



ALISON: It's so not okay

to travel like this.

ALISON (voice-over):

My friend told me

about this synth guru

living in the mountains

of Colombia.

His name is Christian Castagno,

and he's

a Grammy-winning producer.

I reached out to him

and told him

about your Resynator,

and he said he had to see it.

So I'm headed to Minca

to meet him and see

what we can do with it.

ALISON:

Is...

Dnde ests Christian? S?

Dnde est? Dnde ests?

Dnde est?

-DRIVER: Donde Christian.

-D-Donde Christian. Ah.

(door opens)

-Hi, Christian.

-Hey, dude.

-Whoa.

-How's it going?

-Much better. Thank you.

-(laughs)

-Look at that.

-Uh, nice to meet you.

-Nice to meet you. (chuckles)

-(chuckles)

Oh, my goodness.

Um, this is, this is it.

That's it. Oh.

Let's just get right into it.

CHRISTIAN (voice-over):

What a journey.

ALISON:

Yeah. It's been on,

it's been on a little trek.

CHRISTIAN:

Look at this cool thing.

ALISON:

So, hopefully, it's--

everything's still intact

inside, but, um...

Well, I mean, the good news is,

Colombia, you can get

anything fixed.

(laughs) So...

ALISON:

Step one: power.

CHRISTIAN: Step one: power.

Okay, let's see.

(high-pitched electronic notes

playing)

-Ooh, I love it already.

-(both laugh)

ALISON: It already sounds

better than when...

Already it's cool.

(electronic music playing)

CHRISTIAN:

Does a great bass.

(electronic notes buzzing)

Okay, now-now

we're getting somewhere. Okay.

Starting to make friends

with the old Resynator.

-(Alison laughs)

-Hey, buddy.

One of the very, very first

impressions that-that

comes out is that

it clearly has

that old-school, beefy,

like, textured trip,

that "mmm" and "mmm"

in the sound.

It definitely does

sound good, for sure.

How he and Mike did the output

in the oscillators

and the filters

and stuff, that's 99.9% of it,

and apparently your dad

was down with stuff like that.

-Because you could tell

right away. -(chuckles)

-(imitates synth sounds)

-Yeah.

-(laughs) That's super awesome.

-Yeah.

(electronic notes playing)

This beefy little ditty.

(Alison chuckles)



(clucking)

ALISON (voice-over):

Being here with Christian

and his family is magical.

I wish you two

could've known each other.

It's funny how

you can meet someone

and almost instantly

they feel like family.

But then someone who is family

can feel so distant.

JUAN CARLOS (voice-over):

Hola.

-Hey, what's up?

-Hola.

-Hi. Alison.

-Juan Carlos.

Nice to meet you.

So, you guys are Systema Solar?

-Dos.

-ALISON: Dos?

-De siete.

-ALISON: Siete.

-Dos de siete.

-Dos de siete de Systema Solar.

CHRISTIAN: There's more planets

in the solar system

-than these two.

-(laughter)

Thank you for bringing

the thing.

-Resynator.

-I brought the thing.

-You brought the thing.

-I brought the thing.

-Did she ever bring the thing.

-Yeah.

(laughter)

This...

-is the Resynator.

-This is the guy.

CHRISTIAN:

See what you think.

(chuckles)

CHRISTIAN:

It's-it's, it's trippy.

(laughs) It's a super trippy

machine, but...

(electronic notes playing)

So... are we gonna do a track?

-(laughs)

-So, yeah.

-Hello?

-Okay.

-Sold!

-Okay.

CHRISTIAN:

This is a-a Systema Solar track

that we were experimenting

last night with.

The bass line of that track,

I did it with my voice.

-Uh-huh. -Like I had,

I had this loop going.

I had the bass idea was...

(vocalizing bass music)

("Qu Pas" by Systema Solar

playing)

Qu pasa, hermano?

No reaccionamos,

yo no s por qu

(vocalizing bass music

through synthesizer)

ALISON:

Oh, my God.

-Qu es lo que es?

-!Uh!

Vamos pa' delante

Que no hay achante

que nos frene

-!Uh!

-!Oh!

!Oh!

!Oh!

!Oh!

Dicen que nada pasa

Y result que pas

de todo...

JUAN CARLOS (voice-over):

Here in la Sierra Nevada,

you feel the resonance

of that mountain.

(voice-over): It feels, like,

really compatible to have

that instrument

coming alive in here.

(vocalizing bass music

through synthesizer)

Y qu pas?

(laughter)

Qu pasa, hermano?

No reaccionamos,

yo no s por qu

!Uh!

Yeah, yeah. (laughs)

(song continues)

(laughs)

It's only a three-hour flight,

but it's gonna be

a really long one.

-Qu pas?

-Qu pas?

Qu pas?

-Qu pas?

-Qu pas?

Qu pas?

-Qu pas?

-Qu pas?

CHRISTIAN (voice-over):

Synthesizers

that I'd encountered

could almost be thought of

as domesticated animals.

And here was this thing

that was like a--

a wolverine or something,

you know? (laughs)

!Uh!



(song ends)

(birds chirping)

(insects chirring)

Oh, my gosh.

(babbles)

(indistinct chatter)



Daddy!

I've heard stories about him.

I've seen photos.

I've seen videos now.

I've got to meet

his closest friends,

and I'm with his family and...

I don't think I've ever

felt closer to my dad

than I do right now.

CHRISTIAN (voice-over):

The Resynator is the vehicle,

but the mission itself is...

is human.

It's her dad.

(voice-over):

She wanted to know him.

(voice breaking):

She's his child.

It's her dad.



(bass playing funky music)

(electric guitar

playing rock music)

(indistinct chatter)

(rock music playing)

ALISON (voice-over): This is

day two of the NAMM show,

and this Resynator

hasn't been here

for 37 years.

So I was really excited

to bring it

and kind of start

a new chapter for it.

My dad invented a synthesizer

in the '70s,

and they showed this

at the NAMM show back in 1980.

And my father passed away

when I was born,

and I dug this out

of my grandma's attic

-a couple of years ago.

-I love it.

And, um, I'm showing it again,

the same, the same prototype.

"Timbral Image Modulator."

And I got a call

from Brian Kehew,

who's doing the demo,

that it wasn't

tracking pitch properly.



(low-pitch tones)

BRIAN:

Right.

So here's the situation.

It's still not tracking pitch,

and we didn't have enough time

to figure it out,

but we're gonna...

(voice-over):

Oddly enough,

I found out that my dad

and Mike Beigel

had something similar happen

37 years ago in 1980.

The night before the NAMM show,

they were putting

this prototype together,

and it wasn't done,

and they were up

until the crack of dawn,

trying to,

like, solder the boards

and finish everything.

But unfortunately,

there's just not enough time

to figure it out

before we do this demo.

And my Resynator is currently

not working.

It's not tracking the pitch,

so we-we...

(voice-over): The whole day

has just been, like,

kind of exhausting and, um,

and really overwhelming

for more reasons than I can

even think about right now.



(voice-over):

The Resynator's broken.

We don't know what happened,

and I'm so upset.

And this whole time, I never

even tried to play it myself.

I just watched

other people play it,

and now I might never

get the chance to.

And I feel like

I've let you down.

(line ringing)

ALISON (over phone):

Hi, Mom.

TAMMY (over phone):

Hi, sweetie. How was the show?

ALISON: It's broken.

It broke right before the show.

TAMMY:

What?

ALISON:

Yeah, it's not tracking,

so we couldn't do the demo.

TAMMY:

Oh, God. I'm so sorry.

ALISON: I just--

I don't know what I'm gonna do

if we can't get it

working again.

TAMMY: Well, you know,

even if you don't,

it's already done

so much for you.

I mean, look at how far

you've come with this project.

You know how happy

this would have made your dad?

ALISON:

Yeah, I know.

I'm just sick, too,

and kind of over it.

TAMMY: I have a feeling you're

gonna get it working again.

ALISON:

Oh, my God, Richard. (laughs)

-It's working.

-I can't believe it.

If it gets stuck, if it will

no longer track pitch,

just power it off

and power it on again.

We thought that it was

the Digital Frequency

Analyzer chip,

which is this processor

right here.

And it turned out to be this,

the crystal.

So when that's off,

it sets everything else off.

Yeah.

-And they were all bad, too.

-Right.

It's crazy how far we've come.

RICHARD:

Yeah.

And I know you're into this

financially quite a bit, so...

-Yeah.

-(chuckles): It's like...

Dug me a hole.

-RICHARD: Okay, so...

-ALISON: All right.

(Richard chuckles)

Oh, my God.

I can't believe it fits.

RICHARD:

Yeah. (chuckles)

(grunts) Okay.

Uh, just anywhere.

RICHARD:

Okay.

ALISON:

Okay.



-Hi. Alison.

-Mark.

-Great to meet you. Hey.

-So nice to meet you.

-Hi.

-WALLY: How you doing?

ALISON:

Good. How are you?



ALISON (voice-over):

This approach to the invention

was from the musical side

of things,

rather than

the technical side of things.

I found this letter

that was addressed to my dad...

-Wow.

-...in 1982, from Jon Anderson.

-JON (voice-over): Wow.

-That's cool.

There's, like, four songs

we were doing yesterday where,

like, we were missing

this sound.

ALISON:

When my dad died,

I guess his family

-compiled his Rolodex.

-Wow.

Musicians: Ken Aronoff.

-Oh, my God. Why Ken?

I was Kenny. -(laughs)



It's a great bit of machinery

and a great idea.

You can see there's

a great imagination behind it.

The Resynator seemed to have

instant sound.

Your dad was really

creating something

that was the beginning

of a lot of things.

ALISON: But how are you

getting it to do the...

(low flange tone)

I've never heard that before.

It always tends

to have a personality

and like a, like a sonic stamp.

This is fantastic.

It's so great.

(electronic music playing)

Oh, I like that.

It's almost human.

It's almost like

someone talking.

MONEY MARK (voice-over):

Everybody's learning right now

how, uh...

how someone's brain worked.

(Resynated voice):

Hi, everybody. How are you?

Uh, so it's nice

to see everybody.

-Where are you from?

-(Alison laughs)

You heard about Don being

this kind of genius guy

who was kind of, like,

outside of the box,

doing all these weird things

with electronics and stuff.

His smile was so infectious.



FRED (voice-over): Oh,

you know who would love this?

(Resynated voice):

Flaming Lips.

-Oh, yeah.

-They would go crazy over it.

ALISON: I just heard

from the tour manager

that they don't

have time to come.

It was a string of attempts

to get people into the trailer

to play the Resynator,

but, like, I got

Rami Jaffee, who I love.

Whoa. We're communicating.

Yeah, I feel like I know him

better than anybody, actually.

(laughs)

-Probably, probably.

-Yeah.



ALISON (over phone):

Hey, Mama. Guess what.

-TAMMY (over phone): What?

-ALISON: I finally heard

from Peter Gabriel, and he said

he does remember the Resynator

and that he'd be happy

to meet me,

so I'm going to London.



-PETER: Hey.

-ALISON: Hi, Peter.

-Very nice to meet you.

-Nice to finally meet you.

-Great. And you.

-Thank you so much

-for doing this, really.

-You're very welcome.

I really appreciate it.

So, I found my dad's Resynator

-in my grandma's attic.

-Right.

And when I pulled it out,

I also pulled out

a bunch of, um, you know,

old records

and documents

and magazines and stuff.

-PETER: Right. -But out of

a needle in a haystack,

I pulled out

this piece of paper

that I thought looked

pretty interesting.

-PETER: Yeah.

-And it said, "Syco Systems."

And it says,

"We hope that the demand

"for the Resynator,

as is already evident here,

"continues to build up

and that we can look forward

"to many years

of business with you.

"Incidentally,

lurking amongst those people

"grasping, cutting and stabbing

for their first Resynator

"is Peter Gabriel.

"If there were

the remotest possibility

"of him being able

to use one on tour in Europe,

please don't hesitate

to let us know."

It was a pivotal moment

for me because

this was the first time

that I was seeing

something factual

where I could kind of take this

to lead the path into,

"Okay, maybe there is something

that I need to discover

-about this."

-Right.

-So, this is very early days.

-Right.

We definitely had, um,

demo models,

and I... I messed around

with it, too.

-You remember playing it?

-Yeah.

I do remember playing it,

but I think, um...

And I think I probably had it

down in... in Bath

for a day or so.

ALISON: So I-I am interested

to see, like, in what form

you would want to see

the Resynator, but also,

what would you hope

your daughter would do

if she were me?

-Am I, am I missing anything?

-Yeah, 'cause this is

-a search for your dad.

-Yeah.

And that's... you know,

that's a beautiful thing

in itself, so, you know...

But maybe, you know,

a better way to honor it

is rather than trying

to recreate the past--

because he was always wanting

to move on

and-and absorb the future

in his designs--

so maybe you should do that

-and put it in software.

-Yeah.

Yeah. I never really

thought about it like that.

-Yeah.

-Like, I'm trying to go back,

but he was always trying

to push for the future.

-Go forward. Yeah.

-That's great.

Do you feel you're finding more

about your dad in the process?

'Cause that's the important

part of this journey, right?

Yeah. I mean, for sure,

'cause I...

I didn't have

any interest in...

-in learning about him

as a kid. -Right.

'Cause, like I said,

everything was so outlandish

-that it didn't seem relatable

or believable. -Right. Right.

So, now that I'm...

-now that I'm here, especially,

like, I've... -Yeah.

You know, standing outside

the Syco office,

knowing that he was in London

-thirty... seven years ago.

-Yeah.

-Right. Right.

-(laughs) He was here, too.

-Yeah. -And so it's, like,

moments like that

that I n-- I normally

would never, um,

think mattered

or felt any difference...

Yeah.

...now I feel like

there's some sort

of connection there.

Cool, well, Peter,

thank you so much.

Well, good luck. Okay.

-I really appreciate all

of your time. -No, it's okay.

You're very welcome.

This has been really fun

for me.

Great. Well, I wish you...

wish you well

in exploring it and, uh,

bringing it back to life

in whatever form it takes.

(voice-over): To me,

it's... it's Alison's search

for her dad

through this instrument

that is interesting.

She's trying to, um,

feel the work

and in the mind

and heart of her dad

through this journey.

I think Alison will find

something of herself

through learning more

about her dad.

You know, I think we are

inevitably, you know, a product

of our parents

and grandparents.

And so,

the more information we have

about them, there will be clues

and signposts

for our own lives.



ALISON (voice-over):

Emmett told me

you were called a robot

in high school.

Roger said you were shy.

Gordon said you were depressed.

So maybe you created something

you always wanted

to be yourself.

Something with an interesting

and expressive existence

that could filter things out

and shape things.

Something that could sound

like anything

and be anything.

(doorbell rings)

-Hi there.

-How you doing?

-Long time no see.

-(dog barking)

-Good to see you, Mike.

-You, too.

-Hi. I haven't seen you

in a long time either. -Pookie.

-Hey, we're all still here.

-Hey, you look the same,

but Pookie looks

a little older.

-(laughs)

-Pookie.

We do need

whatever tools we're gonna use.

Okay.

So, I've got two main boards

and one DFA board.

We talked about swapping out

these five percent resistors

with one percent.

We're gonna have to do

some de-soldering.

Some de-soldering.

You want to have

good physical contact so that

the solder is not

the conductor.

The solder just

holds everything in place.

-I didn't know that.

-Now you know it.

-Bend it, so it fits right.

-Okay.

So, now we solder.

Hold the soldering iron this

way and don't touch this part

-when it's on.

-Okay.

-This is the part that leaves

a permanent mark. -Yup. Okay.

MIKE:

Solder should flow,

and you don't want to use

too much or too little.



DON (voice-over):

Well, I started in art,

and then got into music

in the '60s,

and one of the reasons

I got into music was

because, as a musician,

you simply picked up

your instrument and played.

I was able to have

the creative experience

with my audience.

The computer comes along

and allows me

to have that immediacy

of being able

to sit down with somebody

and show them

this creative expression.

MIKE (voice-over):

This particular item

was a symbol

of her father's work

and my work,

our cooperative work.

It's a product

that kind of deserved

to be presented

to the public at the time.

And it wasn't.

It was just like a...

a page pulled out of a book.

ALISON: That looks good.

Oh, man, you're so... (laughs)

You're so quick.

That's how it's done.

That was so quick.



It's a profound kind

of a feeling

that a person shows up

who is a representative

on this planet of Don.

It's just one of the stranger

experiences I've had

in a life full of pretty

strange experiences. (chuckles)

While computers

won't replace us...

the computer does a rather

neat job of filling in for us.



(line ringing)

-ROD (over phone): Hello.

-ALISON: Hi. Rod?

-ROD: You're Don's kid.

-I am, yeah.

ROD:

My involvement with your dad

started in

I-I'm pretty sure it was '82.

I was

a quality assurance manager

for a company called Manutek,

and we were the manufacturers

that Don selected

for the Musico Resynator,

like, the first guitar

synthesizer put out there.

ALISON:

Yeah.

ROD: The original prototype run

was for 15 units,

but the plan was

to finish two completely,

because he apparently

had arranged

-to, uh, do a demo

for Paul McCartney. -Wow.

ROD: And he was kind of

counting on that endorsement.

We really grinded

over the details,

setting all

the variable resistors

at just the right setting

and all that kind of crap.

And there was

a lot of adjustment.

We got two units

up and running, and he said,

"Okay, I'm gonna take one

to England with me."



You know, about a week later,

he called us from London,

and he said,

"There's been a glitch.

I'm not getting what I need

out of this thing."

I knew that Don had an early

appointment with McCartney.

And I'm not sure

how it worked out

'cause I never talked

to your dad again.

It's always been my feeling

that maybe the demo

with McCartney

didn't go so well.

You know,

I think after that demo,

he kind of lost interest

in the whole thing.



KITTY (voice-over):

Good moms raise their children,

give them a sense of ethics.

I said,

"When you walk out this door,

"you reflect on this family.

"If you do something great,

we bask in your glory.

If you do something bad,

we share your shame."

ALISON (voice-over):

Grandma Kitty passed away,

and I'm left thinking

about all the things

I never told her because

I didn't feel that I could.

She didn't understand you,

just like

she never understood me.

But I know that she did love

both of us, in her own way.

DEBORAH (voice-over):

Donnie was the real deal,

but I think

he wanted to be somewhere,

like Alison, just taking off

and going to L.A.

and finding herself,

her own way.

But she had

this fabulous mother

who had helped her

with a foundation.

Really, music was

his true love.

He would have been so happy

if he could have just played

in his band

and performed and done that.

He had such a creative mind.

You know,

if he'd had the freedom,

who knows

what he would have done today?

LARRY:

See that?

ALISON: Yeah I haven't looked

through it yet.

I want to look through

all the books real fast.

(indistinct chatter)

LARRY (voice-over): That's why

we saved all of this here.

We did our best to make sure

that she would know him

through his accomplishments

and through the stories

and the things that

we would tell her about him.

He seemed like a superhero.

-Yeah. Good. Yeah. Interesting.

-And as-as wonderful

-as that seems... -Yeah,

it sounds like you might be...

-...it's unbelievable.

-Yeah, right, but it's true.

You know what I mean?

He was not real to me

until I started

seeing his faults.

You have to... you have to know

the good and the bad,

'cause nobody's perfect.

I've heard good things

and very dark and sad things.

But it's real,

and that's what matters.

-Got to be real.

-Okay, well...

-But I love him.

-I lived it.

And I'm connected

to him, and...

That's wonderful.

That's what counts.

I didn't, I didn't get

to meet him. I didn't get--

You lived it, but I didn't.

He did attempt to...

uh, pitch the Resynator

to Stevie Wonder,

and he did try to have

a meeting with Paul McCartney.

Like, there-there are bits

and pieces of these stories

that I've heard

throughout my life that, yeah,

he actually did those things.

He actually sold three units

to Peter Gabriel.

But I would've--

I never believed any of it

until I was like,

"Oh, and he's also a human.

"He also was real.

He also didn't succeed

in everything he did."

And then I was like,

so that stuff that did seem

out of this world

is actually believable now,

and it makes it

that much better.

Okay.

(laughs) I know

you don't like hearing it,

and I know

it's uncomfortable for you,

but it's so important to me.

It's okay that

he was depressed...

GRACE:

I have a glass already.

-Should we open it in here?

-Sure.

Just...

GRACE:

You open it.

ALISON:

I'm gonna do a hefty pour.

GRACE:

(laughs) I think it's probably

-a hefty pour kind of night.

-ALISON: Yeah.

-Are you nervous?

-Yeah.

I've been dreading this

for a while.

I'm just afraid that I'm gonna,

like, read something

that makes me hate him.

GRACE:

What do you think is in here?

I got a text from Sandi.

She told me that she was going

through Kitty's basement--

um, I don't know, like,

a few weeks after Kitty died--

and, like,

found these documents

that she thought

I would want to see.

GRACE: So, your Aunt Sandi,

like, sent you these?

Are these hard copies?

Oh, there's a letter.

ALISON: I'm not sure.

"Alison, your dad

"spoke to me through

his mind somehow

"the afternoon before

"he was declare-declared

brain dead.

"I had gone up to my bedroom

"to change shoes when suddenly

the smell of Don's fragrance,

Obsession for Men..."

(chuckles)

(both laugh)

-"...filled..."

-He was, he was debonair.

Yeah. (laughs)

"...filled the air.

"I was stopped in my tracks,

and his voice said,

"'Take care of my little girl.'

"I said, 'I will.'

"And then the fragrance

immediately left,

"and that was it.

"He was declared dead

that next morning.

"Larry and I will always

be here for you,

along with the rest of

your family. Love you, Sandi."

Oh, geez.

GRACE:

Well, that's heavy.

(sighs)

So, um, this says,

"For Alison."

Okay.

Uh, November 17th, '88.

So, this is, like,

a week before he died.

"I spent nearly four hours

with Alison.

"My mom and I lovingly posed

for Sandi's camera.

"I just couldn't keep away

from Alison.

"She could tell

by the smell of me

"and my voice

that this was Daddy.

"I picked her up

"and almost instantly

she mellowed out

"because she is of my genes.

When she awoke from sleep

and our eyes..." (sniffling)

"...locked,

"and we (stammers)

mimicked each other,

each other's

fac-facial expressions..."

(sobs softly)

(sobbing)

Sorry.

You don't need to be sorry.

I'm okay.

"I looked in her eyes,

and I could see

"so far into her

because she is me.

(sniffling)

"It all seemed

so natural, and yet,

"I've been deprived of these

moments since Alison was born.

"I sing 'A Song for You'

by Leon Russell

"with slightly modified lyrics.

"Every time we're together,

I sing this song to her.

"As she grows, she'll know

that that song f-from--

"and years from now,

when she understands the words,

she'll know my sentiment."

"A Song For You." (sniffles)

"I know your image of me

is what I hope to be

"Treat you kindly,

so can't you see (sniffling)

"There's no one

more important to me

"So, daring, won't you please

see through me?

"Because we're alone now

"And now I'm singing

this song for you

"Well, I love you in a place

"Where there's

no space and time

"I love you for my life,

you are a friend of mine

"And when my life is over

"Remember we were together

'Cause we're alone now, and

I'm singing my song for you."

"When it came time to go,

"my chest heavied, I sobbed,

"and then the tears came.

"A wave of sadness

swept over me

"that Sandi's kind words

could not console.

"The tears streamed down

my face and onto her shoulder.

"I knew I had to leave.

"I dedicated myself

at that moment

"to keep a diary of

my quality time with Alison

"to reflect on and savor again

until I could be with her

the next time."

(sighs)

(exhales heavily)

(sniffling)

(sighs) Oh, God.

Are you okay?

I mean...

I have a record of his,

like, an LP,

that, um,

"A Song For You" is on.

So you knew

that he sang that song.

But I didn't know

it was for me.

And I also have

never listened to it

because I've never listened

to any of his music before.



(tape winding)

("Just For You"

by Don Tavel playing)

(gentle guitar melody)

With all the love

in my heart

I did these all

just for you

And the things

from the start

They came all

from my heart...

ALISON (voice-over):

You were 25

when you began inventing

the Resynator.

And I was 25 when I found it.

Maybe, deep down,

I always knew the Resynator

would lead me to you.

So maybe that's why

it took me so long to finally

get it out of the box,

because I wasn't ready

until now.

The truth is, though,

I wouldn't change the way

I grew up for the world.

I grew up in a place where

I was loved unconditionally.

Loved for trying,

loved for failing,

and everything in between.

You didn't have that.

You don't have to be famous

to be special.

You don't have to have played

with legends to be talented.

And you don't have to be

a genius to be successful.

All of those stories

I heard growing up

are a part of you, sure.

But they don't make you

who you are.

Who you are is who I am,

because I am

the resonance of you.

A vibrant and complex,

flawed but growing human.

Everyone says you were

ahead of your time.

And if that's true,

then maybe I am living

in your time.

A time when you would have

been understood.

So I'm keeping

the Resynator project alive.

For both of us.

The earth, my pillow and

my guitar, they surround me

I went to sleep last night

And no one found me

So I headed for the coast

To spend my time alone

With one that I love most.

("Just For You" by

Don and Alison Tavel playing)

(gentle guitar melody)

With all the love

in my heart

I did this all just for you

And even though we're apart

Time's on our side

shining through

With all the love

in my heart

I feel you understand me

I'm not a perfect man

But you found the beauty

Well, time

Goes by so fast

Yet time

Goes by so slow

But lately,

I've been thinking

Where does the time

really go?

It's moving on

It's moving on,

it's moving on

Time passed by

on down the road

It zoomed past

all I'd ever known

Oh, won't you find my time

And take it

anywhere you want?

I can't make time anymore

It's all just for you

With all the love

in my heart

I went to sleep last night

The earth, my pillow

and my guitar

They surround me

And hold me tight

But my time is moving on

It's moving on,

it's moving on

It's moving on,

it's moving on

-It's moving on.

-(song fades)